#define G_LOG_DOMAIN "gpod-feed-view"

#include "config.h"

#include "gpod-feed-view.h"

#include <gdk/gdk.h>
#include <gtk/gtk.h>
#include <glib/gi18n.h>

/**
 * SECTION:gpod-feed-view
 * @title: GpodFeedView
 * @short_description: A #GtkBox widget for list feeds
 * @include: gpod-feed-view.h
 * @see_also: #GpodFeed, #GpodFeedWidget
 *
 * The #GpodFeedView is an instance #GtkBox, and acts as the primary
 * window/widget for listing feeds in the #GpodWindow<!-- -->'s #GtkStack.
 **/

typedef struct _GpodFeedViewPrivate
{
    GtkWidget *box;
} GpodFeedViewPrivate;

struct _GpodFeedView
{
    GtkBox parent;
};

G_DEFINE_TYPE_WITH_PRIVATE (GpodFeedView, gpod_feed_view, GTK_TYPE_BOX)

/*
 * gpod_feed_view_finalize:
 * @object: An instance of #GpodFeedView
 *
 * Does any last minute clean-ups when the class ends.
 */
static void
gpod_feed_view_finalize (GObject *object)
{
    G_OBJECT_CLASS (gpod_feed_view_parent_class)->finalize(object);
}

/*
 * gpod_feed_view_init:
 * @self: An instance of #GpodFeedView
 *
 * Initializes various aspects of the #GpodFeedView. Anything the #GpodFeedView
 * would need before becoming presented should be done here.
 */
static void
gpod_feed_view_init (GpodFeedView *self)
{
    /* Init views/feeds.ui template */
    gtk_widget_init_template (GTK_WIDGET (self));
}

/*
 * gpod_feed_view_class_init:
 * @klass: An instance of #GpodFeedViewClass
 *
 * Initializes the various virtural functions in #GpodFeedViewClass. In
 * addtition it connects the various #GtkWidgets from the gresource file using
 * gtk_widget_class_set_template_from_resource().
 */
static void
gpod_feed_view_class_init (GpodFeedViewClass *klass)
{
    GObjectClass *object_class = G_OBJECT_CLASS (klass);
    GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);

    object_class->finalize = gpod_feed_view_finalize;

    gtk_widget_class_set_template_from_resource (widget_class,
                                                 PACKAGE_RESOURCES "/ui/views/feed.ui");

    //gtk_widget_class_bind_template_child_private (widget_class, GpodFeedView, box);
}

/**
 * gpod_feed_view_new:
 *
 * Creates a new #GpodFeedView, a custom widget to show all feeds user is
 * subscribed to.
 *
 * ## Usage
 * |[
 * GpodFeedView *feed_view;
 *
 * feed_view = gpod_feed_view_new ();
 * ]|
 *
 * Returns: #GpodFeedView
 */
GpodFeedView *
gpod_feed_view_new ()
{
    return g_object_new (GPOD_TYPE_FEED_VIEW,
                         NULL);
}
